package com.kwai.allin.demo;

import java.io.ByteArrayOutputStream;
import java.io.File;

import android.app.Activity;
import android.content.Intent;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.net.Uri;
import android.os.Bundle;
import android.provider.MediaStore;
import android.support.annotation.NonNull;
import android.support.annotation.Nullable;
import android.support.v4.app.Fragment;
import android.text.TextUtils;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;
import android.widget.Toast;

import com.kwai.allin.demo.test.AppInfoManager;
import com.kwai.allin.demo.test.PayTestHelper;
import com.kwai.allin.demo.ui.ConsoleListView;
import com.kwai.allin.demo.util.DialogHelper;
import com.kwai.allin.demo.util.Util;
import com.kwai.sdk.KwaiPayResultListener;
import com.kwai.sdk.KwaiSdk;
import com.kwai.sdk.OnAccountBindListener;
import com.kwai.sdk.OnExitListener;
import com.kwai.sdk.OnLoginResultListener;
import com.kwai.sdk.OnLogoffResultListener;
import com.kwai.sdk.OnUserQueryListener;
import com.kwai.sdk.base.KwaiErrorCode;
import com.kwai.sdk.callback.KwaiSdkCallback;
import com.kwai.sdk.subbus.account.login.KwaiLoginConstant;
import com.kwai.sdk.subbus.account.login.bean.AccountModel;
import com.kwai.sdk.subbus.account.login.bean.User;
import com.kwai.sdk.subbus.account.login.listeners.ILoginStatusChangeListener;
import com.kwai.sdk.subbus.antiaddiction.AddictionInfo;
import com.kwai.sdk.subbus.antiaddiction.AntiAddictDelegate;
import com.kwai.sdk.subbus.certification.CertificationResultListener;
import com.kwai.sdk.subbus.gamelive.IGameLiveCallback;
import com.kwai.sdk.subbus.share.IShareCallback;

/**
 * @author lvming
 */
public class GameFragment extends Fragment {

  private static final String TAG = "GameFragment";
  private static final String MEDIA_TYPE_VIDEO = "video/*";
  private static final int REQUEST_CODE_SELECT_VIDEO = 1;


  private View mRootView;
  private ConsoleListView consoleView;
  private TextView loginStatus;

  /**
   * TODO 设置全局回掉  必须传入  否则会导致功能不正常
   */
  private final KwaiSdkCallback SDK_CALLBACK = new KwaiSdkCallback() {
    /**
     * @param userclick 是否点击 使用sdk弹窗时候 会有回掉通知cp
     * 隐私弹窗
     */
    @Override
    public void onPrivacyAgree(boolean userclick) {
      consoleView.showLog("GameFragment onSuccess: onPrivacyAgree");
    }

    /**
     * 强制登出
     * 建议游戏在此处理为 先登出 然后调用登陆打开登陆界面
     */
    @Override
    public void forceLogout() {
      consoleView.showLog("GameFragment forceLogout success");
      KwaiSdk.logoff(new OnLogoffResultListener() {
        @Override
        public void onSuccess() {
          login();
        }

        @Override
        public void onFail(int errorCode) {}
      });
    }

    /**
     * 切换账号  用户中心点击 切换账号回掉
     * 建议游戏在此处理为 先登出 然后调用登陆打开登陆界面
     */
    @Override
    public void switchAccount() {
      consoleView.showLog("GameFragment switchAccount");
      KwaiSdk.logoff(new OnLogoffResultListener() {
        @Override
        public void onSuccess() {
          Log.e(TAG, "login status : " + KwaiSdk.isLoginSuccess());
          login();
        }

        @Override
        public void onFail(int errorCode) {}
      });
    }
  };

  @Override
  public void onActivityCreated(@Nullable Bundle savedInstanceState) {
    super.onActivityCreated(savedInstanceState);
    Log.e(TAG, "onActivityCreated");
    //设置全局回调
    KwaiSdk.setCallback(SDK_CALLBACK);
    KwaiSdk.addLoginStatusListener(new ILoginStatusChangeListener() {
      @Override
      public void onLoginStatusChange(int status) {
        switch (status) {
          case KwaiLoginConstant.LoginStatus.NONE_LOGIN:
            loginStatus.setText("登陆状态 : 未登陆");
            break;
          case KwaiLoginConstant.LoginStatus.LOGINING:
            loginStatus.setText("登陆状态 : 登陆中");
            break;
          case KwaiLoginConstant.LoginStatus.LOGIN_SUCCESSED:
            loginStatus.setText("登陆状态 : 已登陆 ");
            break;
          case KwaiLoginConstant.LoginStatus.LOGOFFING:
            loginStatus.setText("登陆状态 : 登出中");
            break;
          default:
            loginStatus.setText("登陆状态 : 异常状态");
            break;
        }
      }
    });
    KwaiSdk.addShareListener(new IShareCallback() {
      @Override
      public void onSuccess() {
//        showLog("分享成功：成功拉起快手分享页");
      }

      @Override
      public void onPublishSuccess() {
//        showLog("分享成功：在快手发布成功");
      }

      @Override
      public void onFail(String errorMsg) {
//        showLog(errorMsg);
      }
    });
  }

  @Nullable
  @Override
  public View onCreateView(@NonNull LayoutInflater inflater, @Nullable ViewGroup container,
      @Nullable Bundle savedInstanceState) {
    Log.e(TAG, "onCreateView");
    if (mRootView == null) {
      mRootView = inflater.inflate(R.layout.main_fragment, container, false);
      loginStatus = mRootView.findViewById(R.id.login_status);
      consoleView = mRootView.findViewById(R.id.lv_log);

      mRootView.findViewById(R.id.login_btn).setOnClickListener(new View.OnClickListener() {
        @Override
        public void onClick(View v) {
          login();
        }
      });

      mRootView.findViewById(R.id.real_name_btn).setOnClickListener(new View.OnClickListener() {
        @Override
        public void onClick(View v) {
          certification();
        }
      });


      mRootView.findViewById(R.id.pay_btn).setOnClickListener(new View.OnClickListener() {
        @Override
        public void onClick(View v) {
          DialogHelper.getInfoFromDialog(getActivity(), "支付", new String[]{"请输入金额"},
              new DialogHelper.ResultCallBack() {
                @Override
                public void onResult(String[] result) {
                  if (result.length <= 0) {
                    return;
                  }
                  int price = 1;
                  try {
                    price = Integer.parseInt(result[0]);
                  } catch (Exception e) {
                    consoleView.showLog("支付金额输入非数字 默认设置1分");
                  }
                  PayTestHelper.callpay(price, new KwaiPayResultListener() {
                    @Override
                    public void onPayFailed(DataFailed dataFailed) {
                      consoleView.showLog(
                          TAG + " onPayFailed:" + dataFailed.errcode + " " + dataFailed.msg);

                    }

                    @Override
                    public void onPaySucceed(DataSucceed dataSucceed) {
                      consoleView
                          .showLog(TAG + " onPaySucceed:" + dataSucceed.info.toString());
                    }
                  });
                }
              });
        }
      });

      mRootView.findViewById(R.id.logoff_btn).setOnClickListener(new View.OnClickListener() {
        @Override
        public void onClick(View v) {
          logoff();
        }
      });
      mRootView.findViewById(R.id.logoff_btn).setOnClickListener(new View.OnClickListener() {
        @Override
        public void onClick(View v) {
          logoff();
        }
      });
      mRootView.findViewById(R.id.switch_account_btn).setOnClickListener(
          new View.OnClickListener() {
            @Override
            public void onClick(View v) {
              switchAccount();
            }
          });
      mRootView.findViewById(R.id.bind_account_view).setOnClickListener(
          new View.OnClickListener() {
            @Override
            public void onClick(View v) {
              bindAccount();
            }
          });
      //显示  用户中心 web 界面
      mRootView.findViewById(R.id.show_user_center).setOnClickListener(
          new View.OnClickListener() {
            @Override
            public void onClick(View v) {
              KwaiSdk.showUserCenter();
            }
          });
      mRootView.findViewById(R.id.exit_app).setOnClickListener(
          new View.OnClickListener() {
            @Override
            public void onClick(View v) {
              exitApp();
            }
          });
      mRootView.findViewById(R.id.query_user).setOnClickListener(
          new View.OnClickListener() {
            @Override
            public void onClick(View v) {
              queryUserInfo();
            }
          });
      mRootView.findViewById(R.id.shareMessage).setOnClickListener(
          new View.OnClickListener() {
            @Override
            public void onClick(View v) {
              shareMessage();
            }
          });
      mRootView.findViewById(R.id.share).setOnClickListener(
          new View.OnClickListener() {
            @Override
            public void onClick(View v) {
              shareVideo();
            }
          });
      mRootView.findViewById(R.id.live_btn).setOnClickListener(
          new View.OnClickListener() {
            @Override
            public void onClick(View v) {
              startLive();
            }
          });
      mRootView.findViewById(R.id.stop_live_btn).setOnClickListener(
          new View.OnClickListener() {
            @Override
            public void onClick(View v) {
              KwaiSdk.stopLive();
            }
          });

    }
    //TODO 必须设置， 当正在游戏中的时候不会弹出防沉迷弹窗，游戏根据自己的需要
    KwaiSdk.setupAddictDelegate(new AntiAddictDelegate() {
      /**
       * @return 是否正在游戏中
       */
      @Override
      public boolean isGaming() {
        return false;
      }

      @Override
      public void didAddictInfoUpdate(AddictionInfo addictionInfo) {
        consoleView.showLog(" 这是回调的Addition信息 : " + addictionInfo);
      }

      /**
       * @return 是否需要自定义防沉迷ui
       */
      @Override
      public boolean enableCustomUI() {
        return false;
      }

    });

      //TODO 下面注释代码设置之后 要处理所有权限申请  如果有特别的权限隐私合规才需要 申请结果请通过KwaiSdk.onRequestPermissionsResult()通知sdk
//    KwaiSdk.setupPermissionDelegate(new PermissionRequestDelegate() {
//      /**
//       * @param i 代理sdk所有权限申请
//       * @param strings
//       */
//      @RequiresApi(api = Build.VERSION_CODES.M)
//      @Override
//      public void requestPermission(int i, String[] strings) {
//        if (getActivity() != null) {
//          getActivity().requestPermissions(strings, i);
//        }
//      }
//    });

    return mRootView;
  }

  @Override
  public void onActivityResult(int requestCode, int resultCode, Intent data) {
    super.onActivityResult(requestCode, resultCode, data);
    if (resultCode == Activity.RESULT_OK) {
      if (requestCode == REQUEST_CODE_SELECT_VIDEO) {
        Uri uri = data.getData();
        try {
          String path = Util.parseFilePath(getContext(), uri);
          if (TextUtils.isEmpty(path)) {
            Toast.makeText(getActivity(), "选择文件为空", Toast.LENGTH_LONG).show();
            return;
          }

          File file = new File(path);
          KwaiSdk.share(getActivity(), file, "", "");
        } catch (Exception e) {
          e.printStackTrace();
          Log.e("MainFragment", "error get video uri:" + uri.toString());
        }
      }
    }
  }

  /**
   * TODO 确认sdk中是否包含分享功能， 如果不包含。不能分享成功
   */
  private void shareMessage() {
    if (!KwaiSdk.isLoginSuccess()) {
      Toast.makeText(getActivity(), "未登录 请点击【登录】", Toast.LENGTH_SHORT).show();
      return;
    }
    String title = "分享的标题";
    String des ="abc消息测试描述" + System.currentTimeMillis();
    String url = "https://www.kuaishou.com/";
    Bitmap bitmap = BitmapFactory.decodeResource(getResources(), R.mipmap.alert_send_fail);
    ByteArrayOutputStream baos = new ByteArrayOutputStream();
    bitmap.compress(Bitmap.CompressFormat.PNG, 50, baos);

    KwaiSdk.shareMessage(getActivity(), url, title, des, baos.toByteArray());
  }
  /**
   * TODO 确认sdk中是否包含分享功能， 如果不包含。不能分享成功
   */
  private void shareVideo() {
    if (!KwaiSdk.isLoginSuccess()) {
      Toast.makeText(getActivity(), "未登录 请点击【登录】", Toast.LENGTH_SHORT).show();
      return;
    }
    Intent albumIntent = new Intent(Intent.ACTION_PICK);
    albumIntent.setDataAndType(MediaStore.Video.Media.EXTERNAL_CONTENT_URI, MEDIA_TYPE_VIDEO);
    startActivityForResult(albumIntent, REQUEST_CODE_SELECT_VIDEO);
  }

  /**
   * TODO 确认sdk中是否扩展版本， 如果不包含，则不能直播
   */
  private void startLive() {
    KwaiSdk.startLive(getActivity(), true, new IGameLiveCallback() {
      @Override
      public void onSuccess() {
        consoleView
            .showLog(TAG + " 直播开启成功" );
      }

      @Override
      public void onFail(String errCode, String errMsg) {
        consoleView
            .showLog(TAG + "直播开启失败： errCode=" + errCode + "  msg=" + errMsg);
      }

      @Override
      public void onLiveEnd(String msg) {
        consoleView
            .showLog(TAG + "直播结束  msg=" + msg);
      }
    });
  }

  /**
   * 实名认证接口
   */
  private void certification() {
    KwaiSdk.certification(new CertificationResultListener() {
      @Override
      public void onSuccess() {
        consoleView.showLog("GameFragment 实名成功");
      }

      @Override
      public void onFailed(int code, String msg) {
        consoleView.showLog("GameFragment 实名失败 " + code + msg);
      }
    });
  }


  /**
   * 登陆
   * 下面五个授权范围 可以根据需要添加， 默认可以不添加
   * "关注的"
   * KwaiSdk.addLoginScope(KwaiLoginConstant.KwaiLoginScope.FLLOWING);
   * "好友"
   * KwaiSdk.addLoginScope(KwaiLoginConstant.KwaiLoginScope.RELATION);
   * "私信"
   * KwaiSdk.addLoginScope(KwaiLoginConstant.KwaiLoginScope.MESSAGE);
   * "直播"
   * KwaiSdk.addLoginScope(KwaiLoginConstant.KwaiLoginScope.LIVE);
   * "观看直播"
   * KwaiSdk.addLoginScope(KwaiLoginConstant.KwaiLoginScope.WATCH_LIVE);
   */
  private void login() {
    KwaiSdk.login(new OnLoginResultListener() {
      @Override
      public void onSuccess(AccountModel accountModel) {
        AppInfoManager.getInstance().setGameUserId(accountModel.getSdkUserId());
        //TODO 新的sdk获取token需要在登陆的情况下调用KwaiSdk.getGameToken()
        // 老sdk可以直接accountModel.getSdkToken() 已经移除该字段
        AppInfoManager.getInstance().setGameToken(KwaiSdk.getGameToken());
        String newText = "登陆状态：已登陆 \n 登陆方式 :" + accountModel.getLoginType() + " \n 是否是刷新登陆: " +
            accountModel.isRefreshLogin() + " \n 授权范围: " + accountModel.getLoginScope();
        loginStatus.setText(newText);
        consoleView.showLog("GameFragment onSuccess:" + accountModel);
      }

      @Override
      public void onFail(int errorCode) {
        consoleView.showLog("GameFragment onFail:" + KwaiErrorCode.getErrorMsg(errorCode, ""));
      }
    });
  }

  private void logoff() {
    KwaiSdk.logoff(new OnLogoffResultListener() {
      @Override
      public void onSuccess() {
        Log.e(TAG, "mLogOff onSuccess");
        consoleView.showLog("GameFragment LogOff: success");
      }

      @Override
      public void onFail(int errorCode) {
        Log.e(TAG, "mLogOff onFailure: " + errorCode);
        if (errorCode == KwaiErrorCode.KWAI_ERROR_NOT_LOGINED) {
          consoleView.showLog(TAG + errorCode + " LogOff: 还未登陆");
        }
      }
    });
  }

  /**
   * 切换账号登陆， 这种登陆在成功之前不会踢出当前账户 必须在登陆状态下调用。
   */
  private void switchAccount() {
    KwaiSdk.switchLogin(new OnLoginResultListener() {
      @Override
      public void onSuccess(AccountModel accountModel) {
        AppInfoManager.getInstance().setGameUserId(accountModel.getSdkUserId());
        //TODO 新的sdk获取token需要在登陆的情况下调用KwaiSdk.getGameToken()
        // 老sdk可以直接accountModel.getSdkToken() 已经移除该字段
        AppInfoManager.getInstance().setGameToken(KwaiSdk.getGameToken());
        String newText = "登陆状态：已登陆 \n 登陆方式 :" + accountModel.getLoginType() + " \n 是否是刷新登陆: " +
            accountModel.isRefreshLogin() + " \n 授权范围: " + accountModel.getLoginScope();
        loginStatus.setText(newText);
        consoleView.showLog("GameFragment onSuccess:" + accountModel);
      }

      @Override
      public void onFail(int errorCode) {
        Log.e(TAG, "mLogOff onFailure: " + errorCode);
        if (errorCode == KwaiErrorCode.KWAI_ERROR_NOT_LOGINED) {
          consoleView.showLog("GameFragment onFail:" + KwaiErrorCode.getErrorMsg(errorCode, ""));
        }
      }
    });
  }

  /**
   * 绑定账号
   */
  private void bindAccount() {
    KwaiSdk.bindAccount(new OnAccountBindListener() {
      @Override
      public void onBindSuccess(boolean isBind, String channel) {
        consoleView.showLog("GameFragment $isbind  onSuccess: $channel");
      }

      @Override
      public void onBindFailure(int errorCode) {
        consoleView
            .showLog("GameFragment onBindFailure:" + KwaiErrorCode.getErrorMsg(errorCode, ""));
      }
    });
  }

  /**
   * 退出游戏二次弹窗， 游戏可以不使用
   */
  private void exitApp() {
    KwaiSdk.exitApp(new OnExitListener() {
      @Override
      public void onExit() {
        getActivity().finish();
      }

      @Override
      public void onCancel() {
        consoleView.showLog("GameFragment  取消退出");
      }

    });
  }

  /**
   * 查询用户信息接口
   */
  private void queryUserInfo() {
    KwaiSdk.queryUserInfo(new OnUserQueryListener() {
      @Override
      public void onSuccess(User user) {
        consoleView.showLog("GameFragment queryUserInfo success " + user);
      }

      @Override
      public void onFail(int errorCode) {
        consoleView.showLog(
            "GameFragment queryUserInfo fail : " + KwaiErrorCode.getErrorMsg(errorCode, ""));
      }
    });
  }

}
