package com.kwai.allin.demo.util;

import java.util.ArrayList;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.DialogInterface;
import android.graphics.Color;
import android.text.TextUtils;
import android.view.ViewGroup;
import android.widget.CheckBox;
import android.widget.EditText;
import android.widget.LinearLayout;
import android.widget.ScrollView;

public class DialogHelper {

  public static void getInfoFromDialog(Activity activity, String title, String[] hints, final ResultCallBack callBack) {
    final LinearLayout layout = new LinearLayout(activity);
    layout.setOrientation(LinearLayout.VERTICAL);
    layout.setBackgroundColor(Color.WHITE);

    if (hints != null && hints.length > 0) {
      for (String hint : hints) {
        EditText et = new EditText(activity);
        et.setTextColor(Color.BLACK);
        et.setHint(hint);
        et.setTag(hint);
        layout.addView(et, new ViewGroup.LayoutParams(ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.WRAP_CONTENT));
      }
    }
    AlertDialog.Builder builder = new AlertDialog.Builder(activity);
    builder.setTitle(TextUtils.isEmpty(title) ? "请输入" : title);
    builder.setView(layout);
    builder.setPositiveButton("确认", new DialogInterface.OnClickListener() {
      @Override
      public void onClick(DialogInterface dialog, int which) {
        int count = layout.getChildCount();
        String[] result = new String[count];
        for (int i = count - 1; i >= 0; i--) {
          result[i] = ((EditText) layout.getChildAt(i)).getText().toString().trim();
        }
        if (callBack != null) {
          callBack.onResult(result);
        }
      }
    });
    builder.setNegativeButton("取消", null);
    builder.show();

  }

  public static void getSelectFromDialog(Activity activity, String title, final String[] hints, final ResultCallBack callBack) {
    ScrollView scrollView = new ScrollView(activity);
    final LinearLayout layout = new LinearLayout(activity);
    layout.setOrientation(LinearLayout.VERTICAL);
    layout.setBackgroundColor(Color.WHITE);
    scrollView.addView(layout);
    if (hints != null && hints.length > 0) {
      for (String hint : hints) {
        CheckBox et = new CheckBox(activity);
        et.setTextColor(Color.BLACK);
        et.setHint(hint);
        et.setTag(hint);
        layout.addView(et, new ViewGroup.LayoutParams(ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.WRAP_CONTENT));
      }
    }
    AlertDialog.Builder builder = new AlertDialog.Builder(activity);
    builder.setTitle(TextUtils.isEmpty(title) ? "请输入" : title);
    builder.setView(scrollView);
    builder.setPositiveButton("确认", new DialogInterface.OnClickListener() {
      @Override
      public void onClick(DialogInterface dialog, int which) {
        int count = layout.getChildCount();
        ArrayList<String> result = new ArrayList<String>();
        for (int i = 0; i < count; i++) {
          CheckBox checkBox = ((CheckBox) layout.getChildAt(i));
          if (checkBox.isChecked()) {
            result.add((String) checkBox.getTag());
          }
        }
        dialog.dismiss();
        if (callBack != null) {
          callBack.onResult(result.toArray(new String[0]));
        }

      }
    });
    builder.setNegativeButton("取消", null);
    builder.show();

  }

  public interface ResultCallBack {
    void onResult(String[] result);
  }
}